@@ -1,8 +1,9 @@
 sde.sim <- function (t0 = 0, T = 1, X0 = 1, N = 100, delta, drift, sigma, 
     drift.x, sigma.x, drift.xx, sigma.xx, drift.t, method = c("euler", 
-        "milstein", "KPS", "milstein2", "cdist","ozaki","shoji"), 
+        "milstein", "KPS", "milstein2", "cdist","ozaki","shoji","EA"), 
 		alpha = 0.5, eta = 0.5, pred.corr = T, rcdist = NULL, theta = NULL,
-	model = c("CIR", "VAS", "OU", "BS")) 
+	model = c("CIR", "VAS", "OU", "BS"),
+	k1, k2, phi, max.psi = 1000, rh, A) 
 {
 	method <- match.arg(method)
 	if(!missing(model)){
@@ -44,7 +45,7 @@ sde.sim <- function (t0 = 0, T = 1, X0 = 1, N = 100, delta, drift, sigma,
         needs.sxx <- TRUE
         needs.dxx <- TRUE
     }
-	if(method == "ozaki" || method == "shoji")
+	if(method == "ozaki" || method == "shoji" || method == "EA")
 	    needs.dx <- TRUE
 	if(method == "shoji"){
 	    needs.dxx <- TRUE
@@ -77,6 +78,7 @@ sde.sim <- function (t0 = 0, T = 1, X0 = 1, N = 100, delta, drift, sigma,
     s1 <- function(t, x) eval(sigma)
     s1.x <- function(t, x) eval(sigma.x)
     s1.xx <- function(t, x) eval(sigma.xx)
+
     if (t0 < 0 || T < 0) 
         stop("please use positives times!")
     if (missing(delta)) {
@@ -87,26 +89,28 @@ sde.sim <- function (t0 = 0, T = 1, X0 = 1, N = 100, delta, drift, sigma,
         T <- t[N + 1]
         warning("T set to =", T, "\n")
     }
-    dt <- (T - t0)/N
+    Dt <- (T - t0)/N
 
 
 	if(method == "model"){
       if(is.null(theta)) 
         stop("please provide a vector of parameters for the model")
      if(model == "CIR")
- 	    X <- sde.sim.cdist(X0, t0, dt, N, rcCIR, theta)
+ 	    X <- sde.sim.cdist(X0, t0, Dt, N, rcCIR, theta)
 	 if(model == "OU")
-	    X <- sde.sim.cdist(X0, t0, dt, N, rcOU, theta)
+	    X <- sde.sim.cdist(X0, t0, Dt, N, rcOU, theta)
 	 if(model == "BS")
-	    X <- sde.sim.cdist(X0, t0, dt, N, rcBS, theta)
+	    X <- sde.sim.cdist(X0, t0, Dt, N, rcBS, theta)
 	  }
 	 
+     if (method == "EA")	 
+      X <- sde.sim.ea(X0, t0, Dt, N, d1, d1.x, k1, k2, phi, max.psi, rh, A)
 
      if (method == "cdist"){
       if(is.null(theta)) 
         stop("please provide a vector of parameters for `rcdist'")
       else
-        X <- sde.sim.cdist(X0, t0, dt, N, rcdist, theta)
+        X <- sde.sim.cdist(X0, t0, Dt, N, rcdist, theta)
      }
 	
      if (method == "ozaki"){ 
@@ -116,7 +120,7 @@ sde.sim <- function (t0 = 0, T = 1, X0 = 1, N = 100, delta, drift, sigma,
 		 stop("drift must depend on `x' and volatility must be constant")
   		if((length(vd) == 1) && (vd != "x"))
 		 stop("drift must depend on `x'")
-		X <- sde.sim.ozaki(X0, t0, dt, N, d1, d1.x, s1)
+		X <- sde.sim.ozaki(X0, t0, Dt, N, d1, d1.x, s1)
 	 }
      if (method == "shoji"){ 
 	    vd <- all.vars(drift)
@@ -125,27 +129,27 @@ sde.sim <- function (t0 = 0, T = 1, X0 = 1, N = 100, delta, drift, sigma,
 		 stop("drift must depend on `x' and/or `t' and volatility must be constant")
   		if((length(vd) == 1) && (vd != "x"))
 		 stop("drift must depend at least on `x'")
-		X <- sde.sim.shoji(X0, t0, dt, N, d1, d1.x, d1.xx, d1.t, s1)
+		X <- sde.sim.shoji(X0, t0, Dt, N, d1, d1.x, d1.xx, d1.t, s1)
 	 }
      if (method == "euler") 
-        X <- sde.sim.euler(X0, t0, dt, N, d1, s1, s1.x, alpha, 
+        X <- sde.sim.euler(X0, t0, Dt, N, d1, s1, s1.x, alpha, 
             eta, pred.corr)
      if (method == "milstein") 
-        X <- sde.sim.milstein(X0, t0, dt, N, d1, s1, s1.x)
+        X <- sde.sim.milstein(X0, t0, Dt, N, d1, s1, s1.x)
      if (method == "milstein2") 
-        X <- sde.sim.milstein2(X0, t0, dt, N, d1, d1.x, d1.xx, 
+        X <- sde.sim.milstein2(X0, t0, Dt, N, d1, d1.x, d1.xx, 
             s1, s1.x, s1.xx)
      if (method == "KPS") {
         require(MASS)
-        Sigma <- matrix(c(dt, 0.5 * dt^2, 0.5 * dt^2, 1/3 * dt^3), 
+        Sigma <- matrix(c(Dt, 0.5 * Dt^2, 0.5 * Dt^2, 1/3 * Dt^3), 
             2, 2)
         tmp <- mvrnorm(N, c(0, 0), Sigma)
         Z <- tmp[, 1]
         U <- tmp[, 2]
-        X <- sde.sim.KPS(X0, t0, dt, N, d1, d1.x, d1.xx, s1, 
+        X <- sde.sim.KPS(X0, t0, Dt, N, d1, d1.x, d1.xx, s1, 
             s1.x, s1.xx, Z, U)
      }
 
-    X <- ts(X, start = t0, deltat = dt)
+    X <- ts(X, start = t0, deltat = Dt)
     invisible(X)
 }
